@@ -9,7 +9,7 @@ use Exporter 'import';
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-12-09'; # DATE
 our $DIST = 'Perinci-Sub-Normalize'; # DIST
-our $VERSION = '0.203'; # VERSION
+our $VERSION = '0.204'; # VERSION
 
 our @EXPORT_OK = qw(
                        normalize_function_metadata
@@ -30,7 +30,7 @@ sub _check {
                     return "Duplicate position $argspec->{pos}" if defined $pos[ $argspec->{pos} ];
                     $pos[ $argspec->{pos} ] = $argname;
                 }
-                if ($argspec->{slurpy}) {
+                if ($argspec->{slurpy} || $argspec->{greedy}) { # greedy is deprecated, but we should keep observing to make us properly strict
                     return "Argument $argname: slurpy=1 without setting pos"
                         unless defined $argspec->{pos};
                     return "Multiple args with slurpy=1" if defined $slurpy_pos;
@@ -41,7 +41,7 @@ sub _check {
             }
             # we have holes
             return "There needs to be more arguments that define pos"
-                if grep { defined } @pos;
+                if grep { !defined } @pos;
             if ($meta->{args_as} && $meta->{args_as} =~ /\Aarray(ref)?\z/) {
                 return "Function accepts array/arrayref but there are arguments with no pos defined"
                     if scalar(keys %$argspecs) > @pos;
@@ -207,7 +207,7 @@ Perinci::Sub::Normalize - Normalize Rinci function metadata
 
 =head1 VERSION
 
-This document describes version 0.203 of Perinci::Sub::Normalize (from Perl distribution Perinci-Sub-Normalize), released on 2022-12-09.
+This document describes version 0.204 of Perinci::Sub::Normalize (from Perl distribution Perinci-Sub-Normalize), released on 2022-12-09.
 
 =head1 SYNOPSIS
 
